#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class GomTestBuySells : Indicator
	{
	
		GomPro.GomOrderFlowProValues  gof;
		
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"This indicator shows how to access Orderflow data";
				Name										= "GomTestBuySells";
				Calculate									= Calculate.OnEachTick;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				
				AddPlot(Brushes.Green,"MaxBuys");
				AddPlot(Brushes.Red,"MaxSells");			
			}
            else if (State == State.DataLoaded)
            {
                StartUp();
            }
            else if (State == State.Terminated)
            {
                if (gof != null) 
					gof.OnUpdatedBarOffset-=OnUpdate; //unsubscribe update event
            }
		}

        protected virtual void StartUp()
        {
			gof = GomOrderFlowProValues(Close,Gom.DeltaLib.DeltaCalcType.BidAsk,false,-1, 0, 1,  				//instantiate de GOF.
										Gom.OrderFlow.ImbalanceDirectionType.Diagonal, Gom.OrderFlow.ImbalanceComparisonType.Ratio, 3, 
										Gom.OrderFlow.ImbalanceDirectionType.None, Gom.OrderFlow.ImbalanceComparisonType.Ratio, 3,0,-1, 3, 0, 3, false, 1, 
										Gom.OrderFlow.ReversalPocPositionType.InDecliningSideHalfOfBar, true,false); 

         	gof.Calculate=this.Calculate; //set calculation mode .
      
			gof.OnUpdatedBarOffset+=OnUpdate;	//subscribe update event from the gof.	
		}
		
		
		void OnUpdate(int i)
		{
			if (CurrentBar<1) return;
			
			//i contains the bar offset. On historical data it will usually be 1, because we wait for the bar to be complete, and on the first tick of the next bar, 
			//we update the completed bar which now has an offset of 1. On realtime data it will be 0.
		
			//gof.BarData contains the buys/sells values from all the bars. it's indexed like a NinjaTrader dataseries do gof.BarData[0] is the last one.
			//iterate the bar fom MinTick to Maxtick
			
			//let's compute the max sell and min sell of last bar
			var bardata=gof.BarData[i];
			int maxbuy=0;
			int maxsell=0;
			
			for (int j=bardata.MinTick; j<=bardata.MaxTick;j++)  // we iterate through all the prices from mintick to maxtick ( real price is xTickSize)
			{
				maxsell= Math.Max(maxsell,bardata.Sells[j]);  // compute maxsells			
				maxbuy=Math.Max(maxbuy,bardata.Buys[j]);	// compute maxbuys
			}
			//update max buys plot at the i offset ( i is 1 or 0)
			MaxBuys[i]=maxbuy;
			//update max sells plot  at the i offset ( i is 1 or 0)
			MaxSells[i]=maxsell;		
			
			
		}
		
		
		protected override void OnBarUpdate()
        {
            gof.Update();
		}
			
	    
		#region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> MaxBuys
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
       public Series<double> MaxSells
        {
            get { return Values[1]; }
        }

        #endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private GomTestBuySells[] cacheGomTestBuySells;
		public GomTestBuySells GomTestBuySells()
		{
			return GomTestBuySells(Input);
		}

		public GomTestBuySells GomTestBuySells(ISeries<double> input)
		{
			if (cacheGomTestBuySells != null)
				for (int idx = 0; idx < cacheGomTestBuySells.Length; idx++)
					if (cacheGomTestBuySells[idx] != null &&  cacheGomTestBuySells[idx].EqualsInput(input))
						return cacheGomTestBuySells[idx];
			return CacheIndicator<GomTestBuySells>(new GomTestBuySells(), input, ref cacheGomTestBuySells);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.GomTestBuySells GomTestBuySells()
		{
			return indicator.GomTestBuySells(Input);
		}

		public Indicators.GomTestBuySells GomTestBuySells(ISeries<double> input )
		{
			return indicator.GomTestBuySells(input);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.GomTestBuySells GomTestBuySells()
		{
			return indicator.GomTestBuySells(Input);
		}

		public Indicators.GomTestBuySells GomTestBuySells(ISeries<double> input )
		{
			return indicator.GomTestBuySells(input);
		}
	}
}

#endregion
